@@ -185,10 +185,8 @@ class hexagon_grid:
                                             datax, how='intersection'),
                                 how = 'union')[['geometry']].copy()
         if hexagon_dis == True:
-            final_hexa["geometry"] = final_hexa["geometry"].apply(lambda geom: geom.wkb)
-            final_hexa = final_hexa.drop_duplicates(["geometry"])
-            final_hexa["geometry"] = final_hexa["geometry"].apply(lambda geom: loads(geom))
-            pdf = gpd.overlay(gdf, final_hexa, how = 'union')
+            final_hexan = final_hexa.drop_duplicates(["geometry"])
+            pdf = gpd.overlay(gdf, final_hexan, how = 'union')
             check_topology(pdf)
             self.geosolution = pdf
         else:
